@@ -15,7 +15,7 @@ This class represents a DNS query result from L<DNS::Unbound>.
 
 =head1 ACCESSORS
 
-This class includes an accessor for each member of C<struct ub_result>
+This class includes an accessor for most members of C<struct ub_result>
 (cf. L<libunbound(3)|https://nlnetlabs.nl/documentation/unbound/libunbound/>).
 
 The following all return scalars:
@@ -26,11 +26,11 @@ The following all return scalars:
 
 =item * C<rcode()>, C<nxdomain()>, C<havedata()>, C<canonname()>
 
-=item * C<secure()>, C<bogus()>, C<why_bogus()>
+=item * C<secure()>, C<bogus()>, C<why_bogus()>, C<answer_packet>
 
 =back
 
-C<data()> returns an array reference of strings that contain the query
+C<data()> returns an array reference of byte strings that contain the query
 result in DNS-native RDATA encoding.
 
 =cut
@@ -51,12 +51,23 @@ use Class::XSAccessor {
         bogus => 'bogus',
         why_bogus => 'why_bogus',
         ttl => 'ttl',
+        answer_packet => 'answer_packet',
     },
 };
 
 =head1 ADDITIONAL METHODS
 
-=head2 $objs_ar = I<OBJ>->to_net_dns()
+=head2 $objs_ar = I<OBJ>->to_net_dns_rrs()
+
+B<IMPORTANT:> This method is DEPRECATED and will be withdrawn in a
+forthcoming version. Please migrate to the following logic instead
+(assuming an instance of this class in C<$result>):
+
+    my $packet = Net::DNS::Packet->new( \$result->answer_packet() );
+
+… which will yield a L<Net::DNS::Packet> instance.
+
+The DEPRECATED method’s documentation follows:
 
 The C<data()> accessor’s return values are raw RDATA. Your application
 likely prefers to work with parsed DNS data, though. This method facilitates
@@ -67,15 +78,11 @@ L<Net::DNS::RR::NS>).
 So, for example, to get a TXT query result’s value as a list of
 character strings, you could do:
 
-    @cstrings = map { $_->txtdata() } @{ $result->to_net_dns() }
-
-(NB: It would be ideal to return a single L<Net::DNS::Packet> instance
-rather than the array reference, but C<struct ub_result> doesn’t expose
-enough of the underlying query’s DNS details for that to make sense.)
+    @cstrings = map { $_->txtdata() } @{ $result->to_net_dns_rrs() }
 
 =cut
 
-sub to_net_dns {
+sub to_net_dns_rrs {
     my ($self) = @_;
 
     local ($@, $!);
